summaryrefslogtreecommitdiffstats
path: root/kmail/kmfiltermgr.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfiltermgr.cpp')
-rw-r--r--kmail/kmfiltermgr.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kmail/kmfiltermgr.cpp b/kmail/kmfiltermgr.cpp
index 565bbcc0..9118d14c 100644
--- a/kmail/kmfiltermgr.cpp
+++ b/kmail/kmfiltermgr.cpp
@@ -125,16 +125,16 @@ int KMFilterMgr::moveMessage(KMMessage *msg) const
void KMFilterMgr::endFiltering(KMMsgBase *msgBase) const
{
- KMFolder *tqparent = msgBase->tqparent();
- if ( tqparent ) {
- if ( tqparent == MessageProperty::filterFolder( msgBase ) ) {
- tqparent->take( tqparent->find( msgBase ) );
+ KMFolder *parent = msgBase->parent();
+ if ( parent ) {
+ if ( parent == MessageProperty::filterFolder( msgBase ) ) {
+ parent->take( parent->find( msgBase ) );
}
else if ( ! MessageProperty::filterFolder( msgBase ) ) {
- int index = tqparent->find( msgBase );
- KMMessage *msg = tqparent->getMsg( index );
- tqparent->take( index );
- tqparent->addMsgKeepUID( msg );
+ int index = parent->find( msgBase );
+ KMMessage *msg = parent->getMsg( index );
+ parent->take( index );
+ parent->addMsgKeepUID( msg );
}
}
MessageProperty::setFiltering( msgBase, false );
@@ -392,7 +392,7 @@ void KMFilterMgr::openDialog( TQWidget *, bool checkForEmptyFilterList )
if( !mEditDialog )
{
//
// We can't use the tqparent as long as the dialog is modeless
// and there is one shared dialog for all top level windows.
//
mEditDialog = new KMFilterDlg( 0, "filterdialog", bPopFilter,
@@ -392,7 +392,7 @@ void KMFilterMgr::openDialog( TQWidget *, bool checkForEmptyFilterList )
{
//
- // We can't use the tqparent as long as the dialog is modeless
+ // We can't use the parent as long as the dialog is modeless
// and there is one shared dialog for all top level windows.
//